Package: ChemoSpecUtils
Type: Package
Title: Functions Supporting Packages ChemoSpec and ChemoSpec2D
Version: 1.0.5
Date: 2025-04-12
Authors@R: c(
    person("Bryan A.", "Hanson",
    role = c("aut", "cre"), email =
    "hanson@depauw.edu",
    comment = c(ORCID = "0000-0003-3536-8246")),
    person("Tejasvi", "Gupta",
      role = "ctb",
      comment = "implemented ggplot2 graphics"))
Description: Functions supporting the common needs of packages 'ChemoSpec' and 'ChemoSpec2D'.
License: GPL-3
Depends: R (>= 3.5)
LazyData: TRUE
Suggests: ChemoSpec (>= 6.0), ChemoSpec2D (>= 0.5), tinytest,
        robustbase, RColorBrewer, amap, irlba, lattice, roxut,
        patchwork, ThreeWay, multiway, mvoutlier
Imports: data.table, ggplot2, ggrepel, plotly, magrittr
URL: https://github.com/bryanhanson/ChemoSpecUtils
BugReports: https://github.com/bryanhanson/ChemoSpecUtils/issues
ByteCompile: TRUE
Encoding: UTF-8
RoxygenNote: 7.3.2
NeedsCompilation: no
Packaged: 2025-04-12 01:31:55 UTC; bryanh
Author: Bryan A. Hanson [aut, cre] (<https://orcid.org/0000-0003-3536-8246>),
  Tejasvi Gupta [ctb] (implemented ggplot2 graphics)
Maintainer: Bryan A. Hanson <hanson@depauw.edu>
Repository: CRAN
Date/Publication: 2025-04-12 15:30:04 UTC
Built: R 4.6.0; ; 2026-04-26 17:03:08 UTC; unix
