# Generated by roxygen2: do not edit by hand

S3method(chkSpectra,Spectra)
S3method(chkSpectra,Spectra2D)
S3method(hcaScores,Spectra)
S3method(hcaScores,Spectra2D)
S3method(plotScores,Spectra)
S3method(plotScores,Spectra2D)
S3method(plotScree,default)
S3method(removeFreq,Spectra)
S3method(removeFreq,Spectra2D)
S3method(removeGroup,Spectra)
S3method(removeGroup,Spectra2D)
S3method(removeSample,Spectra)
S3method(removeSample,Spectra2D)
S3method(sampleDist,Spectra)
S3method(sampleDist,Spectra2D)
S3method(sumGroups,Spectra)
S3method(sumGroups,Spectra2D)
S3method(sumSpectra,Spectra)
S3method(sumSpectra,Spectra2D)
export(.addEllipseInfo)
export(.addLegend)
export(.addMethod)
export(.chkArgs)
export(.chkReqGraphicsPkgs)
export(.colLeaf)
export(.computeEllipses)
export(.distPlot)
export(.drawEllipses)
export(.drawPoints)
export(.extraData)
export(.findNA)
export(.getExtremeCoords)
export(.getLimits)
export(.getVarExplained)
export(.ggAddLegend)
export(.ggAnnotate)
export(.ggRepel)
export(.groupNcolor)
export(.labelExtremes)
export(.plotHCA)
export(.prepLegendCoords)
export(.remGrpSam)
export(.scorePlot)
export(.shrinkLeaf)
export(check4Gaps)
export(checkForPackageWithVersion)
export(chkGraphicsOpt)
export(chkSpectra)
export(conColScheme)
export(hcaScores)
export(plotScores)
export(plotScree)
export(removeFreq)
export(removeGroup)
export(removeSample)
export(rowDist)
export(sampleDist)
export(sumGroups)
export(sumSpectra)
export(updateGroups)
importFrom(data.table,as.data.table)
importFrom(ggplot2,.pt)
importFrom(ggplot2,aes)
importFrom(ggplot2,aes_string)
importFrom(ggplot2,annotate)
importFrom(ggplot2,annotation_custom)
importFrom(ggplot2,element_blank)
importFrom(ggplot2,geom_hline)
importFrom(ggplot2,geom_line)
importFrom(ggplot2,geom_path)
importFrom(ggplot2,geom_point)
importFrom(ggplot2,ggplot)
importFrom(ggplot2,labs)
importFrom(ggplot2,scale_color_manual)
importFrom(ggplot2,scale_x_continuous)
importFrom(ggplot2,scale_y_continuous)
importFrom(ggplot2,theme)
importFrom(ggplot2,theme_bw)
importFrom(ggplot2,xlim)
importFrom(ggplot2,ylim)
importFrom(ggrepel,geom_text_repel)
importFrom(grDevices,rainbow)
importFrom(graphics,abline)
importFrom(graphics,axis)
importFrom(graphics,legend)
importFrom(graphics,lines)
importFrom(graphics,plot)
importFrom(graphics,points)
importFrom(graphics,rect)
importFrom(graphics,text)
importFrom(grid,gList)
importFrom(grid,gTree)
importFrom(grid,gpar)
importFrom(grid,grobTree)
importFrom(grid,linesGrob)
importFrom(grid,pointsGrob)
importFrom(grid,textGrob)
importFrom(grid,unit)
importFrom(magrittr,"%>%")
importFrom(plotly,add_annotations)
importFrom(plotly,ggplotly)
importFrom(plotly,layout)
importFrom(stats,as.dendrogram)
importFrom(stats,as.dist)
importFrom(stats,cor)
importFrom(stats,cov)
importFrom(stats,dendrapply)
importFrom(stats,dist)
importFrom(stats,hclust)
importFrom(stats,is.leaf)
importFrom(stats,median)
importFrom(stats,na.omit)
importFrom(stats,qchisq)
importFrom(stats,quantile)
importFrom(utils,data)
importFrom(utils,str)
